==> scichains-cv-4.1.2-sources.jar: net/algart/executors/modules/opencv/common/MatToNumbers.java <==
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2017-2023 Daniel Alievsky, AlgART Laboratory (http://algart.net)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package net.algart.executors.modules.opencv.common;

import net.algart.executors.modules.util.opencv.O2SMat;
import net.algart.executors.api.data.SNumbers;
import org.bytedeco.opencv.opencv_core.Mat;

public abstract class MatToNumbers extends OpenCVExecutor {
    protected MatToNumbers() {
        addInputMat(DEFAULT_INPUT_PORT);
        addOutputNumbers(DEFAULT_OUTPUT_PORT);
    }

    @Override
    public void process() {
        final Mat source = O2SMat.toMat(getInputMat(), allowInputPackedBits());
        setStartProcessingTimeStamp();
        final SNumbers result = analyse(source);
        setEndProcessingTimeStamp();
        getNumbers().setTo(result);
    }

    public abstract SNumbers analyse(Mat source);

    // May be overridden
    protected boolean allowInputPackedBits() {
        return false;
    }
}

==> scichains-cv-4.3.2-sources.jar: net/algart/executors/modules/opencv/common/MatToNumbers.java <==
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2017-2023 Daniel Alievsky, AlgART Laboratory (http://algart.net)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package net.algart.executors.modules.opencv.common;

import net.algart.executors.modules.opencv.util.O2SMat;
import net.algart.executors.api.data.SNumbers;
import org.bytedeco.opencv.opencv_core.Mat;

public abstract class MatToNumbers extends OpenCVExecutor {
    protected MatToNumbers() {
        addInputMat(DEFAULT_INPUT_PORT);
        addOutputNumbers(DEFAULT_OUTPUT_PORT);
    }

    @Override
    public void process() {
        final Mat source = O2SMat.toMat(getInputMat(), allowInputPackedBits());
        setStartProcessingTimeStamp();
        final SNumbers result = analyse(source);
        setEndProcessingTimeStamp();
        getNumbers().setTo(result);
    }

    public abstract SNumbers analyse(Mat source);

    // May be overridden
    protected boolean allowInputPackedBits() {
        return false;
    }
}
